@@ -169,6 +169,8 @@ struct language_entry {
 #define MSG_DELETED                              113
 #define MSG_EXPIRED                              114
 #define MSG_DEL_SHORT                            115
+#define MSG_TXT_VERSION                          116
+#define MSG_FILTERED_OUT                         117
 
 #ifdef MAIN_FILE
 
@@ -301,6 +303,8 @@ char *de[] = {       /* German */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                                   /* End Of Message Table - NOWHERE*/
 };
 
@@ -426,6 +430,8 @@ char *en[] = {       /* English */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                          /* End Of Message Table      - NOWHERE*/
 };
 
@@ -560,6 +566,8 @@ char *es[] = {       /* Espanol/Spanish */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                               /* End Of Message Table */
 };
 
@@ -684,6 +692,8 @@ char *fi[] = {       /* Finnish */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                              /* End Of Message Table      - NOWHERE*/
 };
 
@@ -810,6 +820,8 @@ char *fr[] = {       /* French */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                                  /* End Of Message Table  - NOWHERE*/
 };
 
@@ -936,6 +948,8 @@ char *is[] = {       /* Icelandic */
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                               /* End Of Message Table      - NOWHERE*/
 };
 
@@ -1067,6 +1081,8 @@ char *se[] = {
   "This message has been deleted from the archive", /* MSG_DELETED -HTML */
   "This message has expired",                       /* MSG_EXPIRED -HTML */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
+  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                             /* End Of Message Table    - NOWHERE*/
 };
 
