@@ -30,7 +30,6 @@
 
 #include "threadprint.h"
 
-#include "mprintf.h"
 #include "proto.h"
 
 #ifdef HAVE_DIRENT_H
@@ -70,7 +69,7 @@ int togdbm(void *gp, struct emailinfo *ep)
   char *exp_time_str = strsav(ep->exp_time == -1 ? ""
 			      : secs_to_iso(ep->exp_time));
   char is_deleted_str[32];
-  msnprintf(is_deleted_str, sizeof(is_deleted_str), "%d", ep->is_deleted);
+  trio_snprintf(is_deleted_str, sizeof(is_deleted_str), "%d", ep->is_deleted);
 
   key.dsize = sizeof(num); /* the key is the message number */
   key.dptr = (char *) &num;
@@ -215,49 +214,52 @@ void fprint_menu(FILE *fp, mindex_t idx, char *archives, char *currentid,
 	fprintf(fp, "<th><a href=\"%s\">%s</a></th>\n", set_about,
 		lang[MSG_ABOUT_THIS_LIST]);
 
-    if (idx != NO_INDEX && !set_reverse) {
-	if (pos == PAGE_TOP)
-	    fprintf(fp, "<th><a href=\"#end\">%s</a></th>\n",
-		    lang[MSG_END_OF_MESSAGES]);
-	else
-	    fprintf(fp, "<th><a name=\"end\" href=\"#\">%s</a></th>\n",
-		    lang[MSG_START_OF_MESSAGES]);
-    }
-
-    for (i = 0; i <= AUTHOR_INDEX; ++i) {
-	if (idx != i && show_index[dlev][i]) {
-	    fprintf(fp, "<th><a href=\"%s\">%s</a></th>\n",
-		    index_name[dlev][i], lang[MSG_DATE_VIEW + i]);
-	    ++count_l;
+    if (set_show_index_links && set_show_index_links != (pos == PAGE_TOP ? 4 : 3)) {
+        if (idx != NO_INDEX && !set_reverse) {
+	    if (pos == PAGE_TOP)
+	        fprintf(fp, "<th><a href=\"#end\">%s</a></th>\n",
+			lang[MSG_END_OF_MESSAGES]);
+	    else
+	        fprintf(fp, "<th><a name=\"end\" href=\"#\">%s</a></th>\n",
+			lang[MSG_START_OF_MESSAGES]);
 	}
-    }
 
-    if (show_index[dlev][ATTACHMENT_INDEX]) {
-	if (idx != ATTACHMENT_INDEX) {
-	    fprintf(fp, "<th><a href=\"%s\">%s</a></th>\n",
-		    index_name[dlev][ATTACHMENT_INDEX],
-		    lang[MSG_ATTACHMENT_VIEW]);
-	    ++count_l;
+	for (i = 0; i <= AUTHOR_INDEX; ++i) {
+	    if (idx != i && show_index[dlev][i]) {
+	        fprintf(fp, "<th><a href=\"%s\">%s</a></th>\n",
+			index_name[dlev][i], lang[MSG_DATE_VIEW + i]);
+		++count_l;
+	    }
+	}
+
+	if (show_index[dlev][ATTACHMENT_INDEX]) {
+	    if (idx != ATTACHMENT_INDEX) {
+	        fprintf(fp, "<th><a href=\"%s\">%s</a></th>\n",
+			index_name[dlev][ATTACHMENT_INDEX],
+			lang[MSG_ATTACHMENT_VIEW]);
+		++count_l;
+	    }
+	}
+	if (subdir && idx != NO_INDEX) {
+	    int f_cols = (subdir->prior_subdir != NULL)
+	      + (subdir->next_subdir != NULL);
+	    const char *colspan = 2*f_cols <= count_l ? " colspan=\"2\"": "";
+	    fprintf(fp, "</tr><tr>");
+	    if (subdir->prior_subdir)
+	        fprintf(fp, "<th%s><a href=\"%s%s%s\">%s, %s</a></th>",
+			colspan, subdir->rel_path_to_top,
+			subdir->prior_subdir->subdir, index_name[idx],
+			lang[MSG_PREV_DIRECTORY], lang[MSG_DATE_VIEW + idx]);
+	    if (subdir->next_subdir)
+	        fprintf(fp, "<th%s><a href=\"%s%s%s\">%s, %s</a></th>",
+			colspan, subdir->rel_path_to_top,
+			subdir->next_subdir->subdir, index_name[idx],
+			lang[MSG_NEXT_DIRECTORY], lang[MSG_DATE_VIEW + idx]);
+	    if (show_index[0][FOLDERS_INDEX])
+	        fprintf(fp, "<th><a href=\"%s%s\">%s</a></th>",
+			subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
+			lang[MSG_FOLDERS_INDEX]);
 	}
-    }
-    if (subdir) {
-	int f_cols = (subdir->prior_subdir != NULL)
-	  + (subdir->next_subdir != NULL);
-	const char *colspan = 2*f_cols <= count_l ? " colspan=\"2\"": "";
-	fprintf(fp, "</tr><tr>");
-	if (subdir->prior_subdir)
-	    fprintf(fp, "<th%s><a href=\"%s%s%s\">%s, %s</a></th>",
-		    colspan, subdir->rel_path_to_top,
-		    subdir->prior_subdir->subdir, index_name[idx],
-		    lang[MSG_PREV_DIRECTORY], lang[MSG_DATE_VIEW + idx]);
-	if (subdir->next_subdir)
-	    fprintf(fp, "<th%s><a href=\"%s%s%s\">%s, %s</a></th>",
-		    colspan, subdir->rel_path_to_top,
-		    subdir->next_subdir->subdir, index_name[idx],
-		    lang[MSG_NEXT_DIRECTORY], lang[MSG_DATE_VIEW + idx]);
-	fprintf(fp, "<th><a href=\"%s%s\">%s</a></th>",
-		subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
-		lang[MSG_FOLDERS_INDEX]);
     }
 
     if (archives && *archives)
@@ -351,7 +353,7 @@ void print_index_header_links(FILE *fp, mindex_t called_from,
     if (subdir) {
 	fprintf(fp, "<br>");
 	if (subdir->prior_subdir)
-	    fprintf(fp, " <a href=\"%s%s\">%s, %s</a>",
+	    fprintf(fp, " <a href=\"%s%s%s\">%s, %s</a>",
 		    subdir->rel_path_to_top, subdir->prior_subdir->subdir,
 		    index_name[dlev][called_from], lang[MSG_PREV_DIRECTORY],
 		    lang[MSG_DATE_VIEW + called_from]);
@@ -360,9 +362,10 @@ void print_index_header_links(FILE *fp, mindex_t called_from,
 		    subdir->rel_path_to_top, subdir->next_subdir->subdir,
 		    index_name[dlev][called_from], lang[MSG_NEXT_DIRECTORY],
 		    lang[MSG_DATE_VIEW + called_from]);
-	fprintf(fp, " <a href=\"%s%s\">%s</a>",
-		subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
-		lang[MSG_FOLDERS_INDEX]);
+	if (show_index[0][FOLDERS_INDEX])
+	    fprintf(fp, " <a href=\"%s%s\">%s</a>",
+		    subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
+		    lang[MSG_FOLDERS_INDEX]);
     }
 
     if (set_about && *set_about)
@@ -463,16 +466,17 @@ void print_index_footer_links(FILE *fp, mindex_t called_from,
 	if (subdir->prior_subdir)
 	    fprintf(fp, " <a href=\"%s%s%s\">%s, %s</a>",
 		    subdir->rel_path_to_top, subdir->prior_subdir->subdir,
-		    index_name[called_from], lang[MSG_PREV_DIRECTORY],
+		    index_name[dlev][called_from], lang[MSG_PREV_DIRECTORY],
 		    lang[MSG_DATE_VIEW + called_from]);
 	if (subdir->next_subdir)
 	    fprintf(fp, " <a href=\"%s%s%s\">%s, %s</a>",
 		    subdir->rel_path_to_top, subdir->next_subdir->subdir,
-		    index_name[called_from], lang[MSG_NEXT_DIRECTORY],
+		    index_name[dlev][called_from], lang[MSG_NEXT_DIRECTORY],
 		    lang[MSG_DATE_VIEW + called_from]);
-	fprintf(fp, " <a href=\"%s%s\">%s</a>",
-		subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
-		lang[MSG_FOLDERS_INDEX]);
+	if (show_index[0][FOLDERS_INDEX])
+	    fprintf(fp, " <a href=\"%s%s\">%s</a>",
+		    subdir->rel_path_to_top, index_name[0][FOLDERS_INDEX],
+		    lang[MSG_FOLDERS_INDEX]);
     }
 
     if (set_about && *set_about)
@@ -610,7 +614,9 @@ void printattachments(FILE *fp, struct header *hp,
 		      struct emailinfo *subdir_email)
 {
     char *subj;
-    char* attdir;
+    char *attdir;
+    const char *rel_path_to_top = (subdir_email ?
+				   subdir_email->subdir->rel_path_to_top : "");
 
     if (hp != NULL) {
 	struct emailinfo *em = hp->data;
@@ -620,8 +626,8 @@ void printattachments(FILE *fp, struct header *hp,
 	    subj = convchars(em->subject);
 
 	    /* See if there's a directory corresponding to this message */
-	    attdir = maprintf("%s%c" DIR_PREFIXER "%04d",
-			      set_dir, PATH_SEPARATOR, em->msgnum);
+	    trio_asprintf(&attdir, "%s%c" DIR_PREFIXER "%04d",
+			  set_dir, PATH_SEPARATOR, em->msgnum);
 	    if (isdir(attdir)) {
 	        DIR *dir = opendir(attdir);
 
@@ -646,9 +652,9 @@ void printattachments(FILE *fp, struct header *hp,
 		    char *filename, *stripped_filename;
 		    const char *fmt2 =
 		      (set_indextable ? 
-		       "<tr><td>&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"%s\">%s</a></td>"
+		       "<tr><td>&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"%s%s\">%s</a></td>"
 		       "<td colspan=\"2\" align=\"center\">(%d %s)</td></tr>\n"
-		       : "<li><a href=\"%s\">%s</a> (%d %s)\n");
+		       : "<li><a href=\"%s%s\">%s</a> (%d %s)\n");
 
 		    int first_time = 1;
 		    while ((entry = readdir(dir))) {
@@ -659,16 +665,18 @@ void printattachments(FILE *fp, struct header *hp,
 			    first_time = 0;
 			    fprintf(fp, "<ol>\n");
 			}
-			filename = maprintf("%s%c%s", attdir,
-					    PATH_SEPARATOR, entry->d_name);
+			trio_asprintf(&filename, "%s%c%s", attdir,
+				      PATH_SEPARATOR, entry->d_name);
 			if (!stat(filename, &fileinfo))
 			    file_size = fileinfo.st_size;
 			free(filename);
-			filename = maprintf(DIR_PREFIXER "%04d%c%s", em->msgnum,
-					    PATH_SEPARATOR, entry->d_name);
+			trio_asprintf(&filename, DIR_PREFIXER "%04d%c%s",
+				      em->msgnum,
+				      PATH_SEPARATOR, entry->d_name);
 			stripped_filename = strchr(entry->d_name, '-');
 			if (stripped_filename)
-			    fprintf(fp, fmt2, filename, stripped_filename+1,
+			    fprintf(fp, fmt2, rel_path_to_top,
+				    filename, stripped_filename+1,
 				    file_size, lang[MSG_BYTES]);
 			free(filename);
 		    }
@@ -822,7 +830,6 @@ char *ConvURLsString(char *line, char *mailid, char *mailsubject)
     return parsed;
 }
 
-
 /*
 ** The heuristics for displaying an otherwise ordinary line (a non-quote,
 ** non-sig, non-inhtml, non-blank line) if 'showhtml' is 1 (which really means
@@ -865,7 +872,11 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
     if (email->is_deleted && set_delete_level != DELETE_LEAVES_TEXT
 	&& !(email->is_deleted == 2
 	     && set_delete_level == DELETE_LEAVES_EXPIRED_TEXT)) {
-        fprintf(fp, lang[email->is_deleted == 2 ? MSG_EXPIRED : MSG_DELETED]);
+        int d_index = MSG_DELETED;
+	if (email->is_deleted == 2) d_index = MSG_EXPIRED;
+	if (email->is_deleted == 4 || email->is_deleted == 8)
+	    d_index = MSG_FILTERED_OUT;
+        fprintf(fp, lang[d_index]);
 	printcomment(fp, "body", "end");
 	if (set_showhr)
 	    fprintf(fp, "<hr noshade>\n");
@@ -937,6 +948,11 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
 			pre = FALSE;
 		  }
 		  fprintf(fp, "<p>\n");
+		} else {
+		  if (!pre) {
+			fprintf(fp, "<pre>\n");
+			pre = TRUE;
+		  }
 		}
 		inheader = FALSE;
 	    }
@@ -1260,6 +1276,8 @@ void writearticles(int startnum, int maxnum)
 	    }
 	}
 
+	email_next_in_thread = nextinthread(email->msgnum);
+
 	/*
 	 * Create the comment fields necessary for incremental updating
 	 */
@@ -1354,7 +1372,7 @@ void writearticles(int startnum, int maxnum)
 	 * Should we print message links ?
 	 */
 
-	if (set_show_msg_links) {
+	if (set_show_msg_links && set_show_msg_links != 4) {
 	    printcomment(fp, "next", "start");
 	    fprintf(fp, "<ul>\n");
 
@@ -1421,7 +1439,6 @@ void writearticles(int startnum, int maxnum)
 
 	    printcomment(fp, "nextthread", "start");
 
-	    email_next_in_thread = nextinthread(email->msgnum);
 	    if (email_next_in_thread) {
 		fprintf(fp, "<li><strong>%s:</strong> ",
 			lang[MSG_NEXT_IN_THREAD]);
@@ -1466,26 +1483,28 @@ void writearticles(int startnum, int maxnum)
 
 	if (!set_usetable) {
             int dlev = (email->subdir != NULL);
-	    if (!set_show_msg_links)
+	    if (!(set_show_msg_links && set_show_msg_links != 4))
 		fprintf(fp, "<ul>\n");
-	    fprintf(fp,"<li><strong>%s %s:</strong> \n",
-		      lang[MSG_MESSAGES], lang[MSG_SORTED_BY]);
-	    if (show_index[dlev][DATE_INDEX])
-	        fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
-			index_name[dlev][DATE_INDEX], num, lang[MSG_DATE]);
-	    if (show_index[dlev][THREAD_INDEX])
-	        fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
-			index_name[dlev][THREAD_INDEX], num, lang[MSG_THREAD]);
-	    if (show_index[dlev][SUBJECT_INDEX])
-	        fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
-			index_name[dlev][SUBJECT_INDEX], num, lang[MSG_SUBJECT]);
-	    if (show_index[dlev][AUTHOR_INDEX])
-	        fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
-			index_name[dlev][AUTHOR_INDEX], num, lang[MSG_AUTHOR]);
-	    if (show_index[dlev][ATTACHMENT_INDEX]) {
-		fprintf(fp, "<a href=\"%s\">[ %s ]</a>\n",
-			index_name[dlev][ATTACHMENT_INDEX],
-			lang[MSG_ATTACHMENT]);
+	    if (set_show_index_links && set_show_index_links != 4) {
+	        fprintf(fp,"<li><strong>%s %s:</strong> \n",
+			lang[MSG_MESSAGES], lang[MSG_SORTED_BY]);
+	        if (show_index[dlev][DATE_INDEX])
+		    fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
+			    index_name[dlev][DATE_INDEX], num, lang[MSG_DATE]);
+		if (show_index[dlev][THREAD_INDEX])
+		    fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
+			    index_name[dlev][THREAD_INDEX], num, lang[MSG_THREAD]);
+		if (show_index[dlev][SUBJECT_INDEX])
+		    fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
+			    index_name[dlev][SUBJECT_INDEX], num, lang[MSG_SUBJECT]);
+		if (show_index[dlev][AUTHOR_INDEX])
+		    fprintf(fp, "<a href=\"%s#%d\">[ %s ]</a>\n",
+			    index_name[dlev][AUTHOR_INDEX], num, lang[MSG_AUTHOR]);
+		if (show_index[dlev][ATTACHMENT_INDEX]) {
+		    fprintf(fp, "<a href=\"%s\">[ %s ]</a>\n",
+			    index_name[dlev][ATTACHMENT_INDEX],
+			    lang[MSG_ATTACHMENT]);
+		}
 	    }
 
 	    if (set_custom_archives && *set_custom_archives)
@@ -1517,7 +1536,7 @@ void writearticles(int startnum, int maxnum)
 	    }
 	}
 
-	if (set_show_msg_links || !set_usetable)
+	if ((set_show_msg_links && set_show_msg_links != 4) || !set_usetable)
 	    fprintf(fp, "</ul>\n");
 
 	if (set_linkquotes || set_showhtml == 2)
@@ -1535,7 +1554,7 @@ void writearticles(int startnum, int maxnum)
 	 * Should we print out the message links ?
 	 */
 
-	if (set_show_msg_links) {
+	if (set_show_msg_links && set_show_msg_links != 3) {
 	  /* JK: removed a <p>\n here */
 	    fprintf(fp, "<ul>\n");
 
@@ -1630,28 +1649,30 @@ void writearticles(int startnum, int maxnum)
 			PAGE_BOTTOM, email->subdir);
 	else {
 	      int dlev = (email->subdir != NULL);
-	      if (!set_show_msg_links)
+	      if (!(set_show_msg_links && set_show_msg_links != 3))
 		  fprintf(fp, "<ul>\n");
-	      fprintf(fp,"<li><strong>%s %s:</strong> \n",
-		      lang[MSG_MESSAGES], lang[MSG_SORTED_BY]);
-	      if (show_index[dlev][DATE_INDEX])
-		  fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
-			  index_name[dlev][DATE_INDEX], num, lang[MSG_DATE]);
-	      if (show_index[dlev][THREAD_INDEX])
-		  fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
-			  index_name[dlev][THREAD_INDEX], num,
-			  lang[MSG_THREAD]);
-	      if (show_index[dlev][SUBJECT_INDEX])
-		  fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
-			  index_name[dlev][SUBJECT_INDEX], num,
-			  lang[MSG_SUBJECT]);
-	      if (show_index[dlev][AUTHOR_INDEX])
-		  fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
-			  index_name[dlev][AUTHOR_INDEX], num,
-			  lang[MSG_AUTHOR]);
-	      if (show_index[dlev][ATTACHMENT_INDEX]) {
-		  fprintf(fp, "<a href=\"%s\">[ %s ]</a>\n",
-			  index_name[dlev][ATTACHMENT_INDEX], lang[MSG_ATTACHMENT]);
+	      if (set_show_index_links && set_show_index_links != 3) {
+		  fprintf(fp,"<li><strong>%s %s:</strong> \n",
+			  lang[MSG_MESSAGES], lang[MSG_SORTED_BY]);
+		  if (show_index[dlev][DATE_INDEX])
+		      fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
+			      index_name[dlev][DATE_INDEX], num, lang[MSG_DATE]);
+		  if (show_index[dlev][THREAD_INDEX])
+		      fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
+			      index_name[dlev][THREAD_INDEX], num,
+			      lang[MSG_THREAD]);
+		  if (show_index[dlev][SUBJECT_INDEX])
+		      fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
+			      index_name[dlev][SUBJECT_INDEX], num,
+			      lang[MSG_SUBJECT]);
+		  if (show_index[dlev][AUTHOR_INDEX])
+		      fprintf(fp,"<a href=\"%s#%d\">[ %s ]</a>\n",
+			      index_name[dlev][AUTHOR_INDEX], num,
+			      lang[MSG_AUTHOR]);
+		  if (show_index[dlev][ATTACHMENT_INDEX]) {
+		      fprintf(fp, "<a href=\"%s\">[ %s ]</a>\n",
+			      index_name[dlev][ATTACHMENT_INDEX], lang[MSG_ATTACHMENT]);
+		  }
 	      }
 	      if (set_custom_archives && *set_custom_archives)
 		  fprintf(fp,"<li><strong>%s:</strong> %s\n", 
@@ -1682,6 +1703,11 @@ void writearticles(int startnum, int maxnum)
 	      fprintf(fp, "</ul>\n");
 	}
 
+	if (set_txtsuffix) {
+	    fprintf(fp, "<p><a href=\"%.4d.%s\">%s</a>",
+		    email->msgnum, set_txtsuffix, lang[MSG_TXT_VERSION]);
+	}
+
 	printfooter(fp, mhtmlfooterfile, set_label, set_dir,
 		    email->subject, filename);
 
@@ -2577,22 +2603,26 @@ void write_toplevel_indices(int amountmsgs)
     else
 	newfile = 1;
 
-    if ((fp = fopen(filename, "w")) == NULL) {
+    if (!show_index[0][FOLDERS_INDEX])
+	fp = NULL;
+    else if ((fp = fopen(filename, "w")) == NULL) {
 	sprintf(errmsg, "%s \"%s\".", lang[MSG_COULD_NOT_WRITE], filename);
 	progerr(errmsg);
     }
-    print_index_header(fp, set_label, set_dir, subject, filename);
-    if (!set_usetable) 
-        print_index_header_links(fp, FOLDERS_INDEX, firstdatenum, lastdatenum,
-				 amountmsgs, NULL);
-    else {
-	fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_TOP, NULL);
-	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added an extra <p> here */
-	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n"); 
+    if (fp) {
+	print_index_header(fp, set_label, set_dir, subject, filename);
+	if (!set_usetable) 
+            print_index_header_links(fp, FOLDERS_INDEX, firstdatenum,
+				     lastdatenum, amountmsgs, NULL);
+	else {
+	    fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_TOP, NULL);
+	    fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
+	    /* JK: added an extra <p> here */
+	    if (set_showhr)
+	        fprintf(fp, "<hr noshade><p>\n"); 
+	}
+	fprintf(fp, "<table>\n");
     }
-    fprintf(fp, "<table>\n");
     for (sd = folders; sd != NULL; sd = sd->next_subdir) {
 	int started_line = 0;
 	int empties = 0;
@@ -2619,6 +2649,7 @@ void write_toplevel_indices(int amountmsgs)
 		    break;
 	    }
 
+	    if (!fp) continue;
 	    if (!sd->count) {
 		if(started_line)
 		    fprintf(fp, "<td></td>");
@@ -2636,30 +2667,32 @@ void write_toplevel_indices(int amountmsgs)
 			sd->subdir, index_name[1][j], indextypename[j]);
 	    }
 	}
-	if (started_line) fprintf(fp, "</tr>\n");
+	if (started_line && fp) fprintf(fp, "</tr>\n");
     }
-    fprintf(fp,"</table>\n");
+    if (fp) {
+	fprintf(fp,"</table>\n");
 
-    if (!set_usetable) {
-	/* 
-	 * Print out archive information links at the bottom of the index
-	 */
-	print_index_footer_links(fp, FOLDERS_INDEX, lastdatenum, amountmsgs,
-				 NULL);
-    }
-    else {
-	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
-	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
-	fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_BOTTOM, NULL);
-    }
-    printfooter(fp, ihtmlfooterfile, set_label, set_dir, subject, filename);
+	if (!set_usetable) {
+	    /* 
+	     * Print out archive information links at the bottom of the index
+	     */
+	    print_index_footer_links(fp, FOLDERS_INDEX, lastdatenum,
+				     amountmsgs, NULL);
+	}
+	else {
+	    if (set_showhr)
+	        fprintf(fp, "<hr noshade>\n");
+	    fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
+	    fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_BOTTOM, NULL);
+	}
+	printfooter(fp, ihtmlfooterfile, set_label, set_dir, subject, filename);
+	fclose(fp);
 
-    if (newfile && chmod(filename, set_filemode) == -1) {
-	sprintf(errmsg, "%s \"%s\": %o.",
-		lang[MSG_CANNOT_CHMOD], filename, set_filemode);
-	progerr(errmsg);
+	if (newfile && chmod(filename, set_filemode) == -1) {
+	    sprintf(errmsg, "%s \"%s\": %o.",
+		    lang[MSG_CANNOT_CHMOD], filename, set_filemode);
+	    progerr(errmsg);
+	}
     }
-    fclose(fp);
     free(filename);
 }
