@@ -1,5 +1,5 @@
 /*
-** $Id: setup.c,v 1.15 2001/04/09 19:19:20 pcm Exp $
+** $Id: setup.c,v 1.19 2001/05/12 01:45:21 pcm Exp $
 */
 
 #include "hypermail.h"
@@ -18,6 +18,7 @@ char *set_about;
 char *set_dir;
 char *set_defaultindex;
 char *set_default_top_index;
+char *set_txtsuffix;
 
 bool set_overwrite;
 bool set_inlinehtml;
@@ -29,7 +30,8 @@ bool set_showheaders;
 bool set_showbr;
 bool set_showhr;
 bool set_showreplies;
-bool set_show_msg_links;
+int set_show_msg_links;
+int set_show_index_links;
 bool set_usetable;
 bool set_indextable;
 bool set_iquotes;
@@ -89,6 +91,10 @@ struct hmlist *set_ignore_types = NULL;
 struct hmlist *set_show_headers = NULL;
 struct hmlist *set_avoid_indices = NULL;
 struct hmlist *set_avoid_top_indices = NULL;
+struct hmlist *set_filter_out = NULL;
+struct hmlist *set_filter_require = NULL;
+struct hmlist *set_filter_out_full_body = NULL;
+struct hmlist *set_filter_require_full_body = NULL;
 
 char *set_ihtmlheader;
 char *set_ihtmlfooter;
@@ -167,7 +173,7 @@ struct Config cfg[] = {
      "# date, thread, author, and subject. When using the folder_by_date or\n"
      "# msgsperfolder options, this option applies to subdirectories.\n"},
 
-    {"avoid_top_indices", &set_avoid_top_indices, "date thread author subject", CFG_LIST,
+    {"avoid_top_indices", &set_avoid_top_indices, NULL, CFG_LIST,
      "# This is a list of index files to not generate for the top\n"
      "# directory of an archive using the folder_by_date or\n"
      "# msgsperfolder option. Valid types are date, thread, author, \n"
@@ -227,10 +233,20 @@ struct Config cfg[] = {
      "# Set this to On to show all replies to a message as links\n"
      "# in article files.\n"},
 
-    {"show_msg_links", &set_show_msg_links, BTRUE, CFG_SWITCH,
-     "# Set this to On to put the individual message links at the top\n"
-     "# of the individual message pages. Set this to Off to produce pages\n"
-     "# without the Next, Previous, Reply, In-Reply-To, etc. links.\n"},
+    {"show_msg_links", &set_show_msg_links, INT(1), CFG_INTEGER,
+     "# Set this to 1 to put the individual message links at the top\n"
+     "# of the individual message pages. Set this to 0 to produce pages\n"
+     "# without the Next, Previous, Reply, In-Reply-To, etc. links. Set\n"
+     "# it to 3 to produce those links only at the top of the message\n"
+     "# pages, or 4 to produce those links only at the bottom of the\n"
+     "# message.\n"},
+
+    {"show_index_links", &set_show_index_links, INT(1), CFG_INTEGER,
+     "# Set this to 1 to show links to index pages from the top and\n"
+     "# bottom of each message file. Set it to 0 to avoid those links.\n"
+     "# Set it to 3 to show the links only at the top of the message\n"
+     "# pages, or 4 to produce those links only at the bottom of the\n"
+     "# message.\n"},
 
     {"usetable", &set_usetable, BFALSE, CFG_SWITCH,
      "# Setting this variable to On will tell Hypermail to generate\n"
@@ -525,6 +541,34 @@ struct Config cfg[] = {
      "# Deleted and expired messages are removed from the index files\n"
      "# regardless of the delete_level selection.\n"},
 
+    {"txtsuffix", &set_txtsuffix, NULL, CFG_STRING,
+     "# If you want the original mail messages archived in individual files,\n"
+     "# set this to the extension that you want these messages to have\n"
+     "# (recommended value: txt).\n"},
+
+    {"filter_out", &set_filter_out, NULL, CFG_STRINGLIST,
+     "# Delete from the html archives any message having a header line\n"
+     "# which matches any of these expressions. Uses the same rules for\n"
+     "# deletion as the expires option. The expressions use the same\n"
+     "# syntax as Perl regular expressions.\n"},
+
+    {"filter_require", &set_filter_require, NULL, CFG_STRINGLIST,
+     "# Delete from the html archives any message not having header lines\n"
+     "# which match each of these expressions. Uses the same rules for\n"
+     "# deletion as the expires option. The expressions use the same\n"
+     "# syntax as Perl regular expressions.\n"},
+
+    {"filter_out_full_body", &set_filter_out_full_body, NULL, CFG_STRINGLIST,
+     "# Delete from the html archives any message having a line\n"
+     "# which matches any of these expressions. Uses the same rules for\n"
+     "# deletion as the expires option. The expressions use the same\n"
+     "# syntax as Perl regular expressions.\n"},
+
+    {"filter_require_full_body", &set_filter_require_full_body, NULL, CFG_STRINGLIST,
+     "# Delete from the html archives any message not having lines\n"
+     "# which match each of these expressions. Uses the same rules for\n"
+     "# deletion as the expires option. The expressions use the same\n"
+     "# syntax as Perl regular expressions.\n"},
 };
 
 /* ---------------------------------------------------------------- */
@@ -558,6 +602,7 @@ void MakeConfig(bool comments)
 			    cfg[i].def ? (char *)cfg[i].def : "");
 		break;
 	    case CFG_LIST:
+	    case CFG_STRINGLIST:
 		if (cfg[i].changed) {
 		    print_list(cfg[i].label,
 			       *(struct hmlist **)cfg[i].value);
@@ -654,6 +699,18 @@ void PreConfig(void)
 	    else
 		*(struct hmlist **)cfg[i].value = NULL;
 	    break;
+	case CFG_STRINGLIST:
+	    if (defval) {
+                char *tpstr;
+                tpstr = strsav(defval);
+		*(struct hmlist **)cfg[i].value = NULL;
+		*(struct hmlist **)cfg[i].value =
+		    (void *)add_2_list(*(struct hmlist **)cfg[i].value, tpstr);
+                free(tpstr);
+            }
+	    else
+		*(struct hmlist **)cfg[i].value = NULL;
+	    break;
 	default:
 	    break;
 	}
@@ -682,6 +739,7 @@ void PostConfig(void)
 	show_index[0][THREAD_INDEX]  = !inlist(set_avoid_top_indices, "thread");
 	show_index[0][ATTACHMENT_INDEX] = !inlist(set_avoid_top_indices, "attachments")
 	    && set_attachmentsindex;
+	show_index[0][FOLDERS_INDEX]  = !inlist(set_avoid_top_indices, "folders");
     }
     else {
 	for (i = 0; i <= ATTACHMENT_INDEX; ++i)
@@ -751,7 +809,12 @@ int ConfigAddItem(char *cfg_line)
 		    break;
 		case CFG_INTEGER:
 		    /* get an integer using any base */
-		    *(int *)cfg[i].value = strtol(towhat, NULL, 0);
+		    /* ON/YES support is for options that used to be 
+		       CFG_SWITCH's */
+		    if (!strcasecmp("ON", towhat) || !strcasecmp("YES", towhat))
+			*(int *)cfg[i].value = 1;
+		    else
+		        *(int *)cfg[i].value = strtol(towhat, NULL, 0);
 		    break;
 		case CFG_OCTAL:
 		    /* get an octal number */
@@ -775,6 +838,25 @@ int ConfigAddItem(char *cfg_line)
 		    *(struct hmlist **)cfg[i].value =
 		       (void *)add_list(*(struct hmlist **)cfg[i].value,towhat);
 		    break;
+
+		case CFG_STRINGLIST:
+
+                    /* Is this the first time that it's been called
+                     * for this list ? If so then there is a value
+                     * being set for the list via a config file.
+                     * In the case of lists we need to replace the
+                     * current value with the new material completely.
+                     */
+                    if (cfg[i].changed == FALSE) { /* first time through ? */
+                        if (cfg[i].value) {
+                            if (*(struct hmlist **)cfg[i].value)
+                                 free(*(struct hmlist **)cfg[i].value);
+		            *(struct hmlist **)cfg[i].value = NULL;
+                        }
+                    }
+		    *(struct hmlist **)cfg[i].value =
+		       (void *)add_2_list(*(struct hmlist **)cfg[i].value,towhat);
+		    break;
 		default:
 		    break;
 		}
@@ -820,6 +902,7 @@ void ConfigCleanup(void)
     for (i = 0; i < sizeof(cfg) / sizeof(cfg[0]); i++) {
 	switch (cfg[i].flags) {
 	case CFG_LIST:
+	case CFG_STRINGLIST:
 	    if (cfg[i].value) {
 		if (*(struct hmlist **)cfg[i].value)
 		    free(*(struct hmlist **)cfg[i].value);
@@ -847,18 +930,21 @@ void dump_config(void)
 
     printf("set_language = %s\n",set_language ? set_language : "Not Used");
     printf("set_htmlsuffix = %s\n",set_htmlsuffix ? set_htmlsuffix : "Not Used");
-    printf("set_mbox = %s\n",*set_mbox ? set_mbox : "Not Used");
+    printf("set_mbox = %s\n", set_mbox ? set_mbox : "Not Used");
     printf("set_archives = %s\n",set_archives ? set_archives : "Not set");
     printf("set_custom_archives = %s\n",set_custom_archives ? set_custom_archives : "Not set");
     printf("set_about = %s\n",set_about ? set_about : "Not set");
     printf("set_dir = %s\n",set_dir ? set_dir : "Not set");
     printf("set_defaultindex = %s\n",set_defaultindex ? set_defaultindex : "Not set");
-    
+    printf("set_default_top_index = %s\n",set_default_top_index ? set_default_top_index : "Not set");
+
     printf("set_label = %s\n",set_label ? set_label : "Not set");
+    printf("set_append_filename = %s\n",set_append_filename ? set_append_filename : "Not set");
     printf("set_dateformat = %s\n",set_dateformat ? set_dateformat : "Not set");
     printf("set_stripsubject = %s\n",set_stripsubject ? set_stripsubject : "Not set");
     printf("set_mailcommand = %s\n",set_mailcommand ? set_mailcommand : "Not set");
-    printf("set_bodymailcommand = %s\n",set_bodymailcommand ? set_bodymailcommand : "Not set");
+    printf("set_replymsg_command = %s\n",set_replymsg_command ? set_replymsg_command : "Not set");
+    printf("set_newmsg_command = %s\n",set_newmsg_command ? set_newmsg_command : "Not set");
     printf("set_mailto = %s\n",set_mailto ? set_mailto : "Not set");
     printf("set_hmail = %s\n",set_hmail ? set_hmail : "Not set");
     printf("set_domainaddr = %s\n",set_domainaddr ? set_domainaddr : "Not set");
@@ -866,6 +952,13 @@ void dump_config(void)
     printf("set_icss_url = %s\n",set_icss_url ? set_icss_url : "Not set");
     printf("set_mcss_url = %s\n",set_mcss_url ? set_mcss_url : "Not set");
 
+    printf("set_attachmentlink = %s\n",set_attachmentlink ? set_attachmentlink : "Not set");
+    printf("set_link_to_replies = %s\n",set_link_to_replies ? set_link_to_replies : "Not set");
+    printf("set_quote_link_string = %s\n",set_quote_link_string ? set_quote_link_string : "Not set");
+    printf("set_folder_by_date = %s\n",set_folder_by_date ? set_folder_by_date : "Not set");
+    printf("set_describe_folder = %s\n",set_describe_folder ? set_describe_folder : "Not set");
+    printf("set_latest_folder = %s\n",set_latest_folder ? set_latest_folder : "Not set");
+
     /* Boolean or interger */
 
     printf("set_overwrite = %d\n",set_overwrite);
@@ -884,16 +977,32 @@ void dump_config(void)
     printf("set_indextable = %d\n",set_indextable);
     printf("set_iquotes = %d\n",set_iquotes);
     printf("set_eurodate = %d\n",set_eurodate);
+    printf("set_isodate = %d\n",set_isodate);
+    printf("set_gmtime = %d\n",set_gmtime);
     printf("set_require_msgids = %d\n",set_require_msgids);
     printf("set_discard_dup_msgids = %d\n",set_discard_dup_msgids);
     printf("set_usemeta = %d\n",set_usemeta);
     printf("set_uselock = %d\n",set_uselock);
+    printf("set_locktime = %d\n",set_locktime);
     printf("set_ietf_mbox = %d\n",set_ietf_mbox);
+#ifdef GDBM
+    printf("set_usegdbm = %d\n",set_usegdbm);
+#endif
+    printf("set_append = %d\n",set_append);
     printf("set_thrdlevels = %d\n",set_thrdlevels);
     printf("set_dirmode = %04o\n",set_dirmode);
     printf("set_filemode = %04o\n",set_filemode);
     printf("set_spamprotect = %04o\n",set_spamprotect);
     printf("set_attachmentsindex = %04o\n",set_attachmentsindex);
+    printf("set_linkquotes = %d\n",set_linkquotes);
+    printf("set_searchbackmsgnum = %d\n",set_searchbackmsgnum);
+    printf("set_quote_hide_threshold = %d\n",set_quote_hide_threshold);
+    printf("set_thread_file_depth = %d\n",set_thread_file_depth);
+    printf("set_monthly_index = %d\n",set_monthly_index);
+    printf("set_yearly_index = %d\n",set_yearly_index);
+    printf("set_msgsperfolder = %d\n",set_msgsperfolder);
+    printf("set_iso2022jp = %d\n",set_iso2022jp);
+    printf("set_delete_level = %d\n",set_delete_level);
 
     if (!set_ihtmlheader)
         printf("set_ihtmlheader = Not set\n");
@@ -934,6 +1043,11 @@ void dump_config(void)
     print_list("set_prefered_types",set_prefered_types);
     print_list("set_ignore_types",set_ignore_types);
     print_list("set_show_headers", set_show_headers);
+    print_list("set_avoid_top_indices", set_avoid_top_indices);
+    print_list("set_avoid_indices", set_avoid_indices);
+    print_list("set_deleted", set_deleted);
+    print_list("set_expires", set_expires);
+    print_list("set_delete_msgnum", set_delete_msgnum);
 
 }
 
